Troubleshooting — mod_wsgi 4.8.0 documentation

# Troubleshooting

If you are having problems getting mod_wsgi to start up or do what you want it to do, first off ensure that you read the following documents:

- Installation Issues
- Configuration Issues
- Application Issues

You can also do some basic checking of your installation and configuration to validate that how it is setup is how you expect it to be. See the following document:

- Checking Your Installation

If none of the common issues match up with the problem you are seeing and are after other ideas, or you have the need to perform more low level debugging, check out the User Guides.